# PyOKR
A Python-based optokinetic reflex analysis tool to measure and quantify eye tracking motion in three dimensions. Video-oculography data can be modeled computationally to quantify specific tracking speeds and ability in horizontal and vertical space. 

**Requirements**: 

- Python >= 3.8

- Spyder IDE via Anaconda (suggested for interactive graphs)

**Imports**:

- PyQT5

- Pandas

- Matplotlib

- Numpy

- Sklearn.neighbors (from scikit)

- Scipy

- SymPy

- Pandasgui

